@@ -2,22 +2,38 @@
 # 
 #       Experimental!
 #       Some code from Alpha.
+#
+#  Copyright (c) 2007 Mats Bengtsson
+#  
+#   This program is free software: you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation, either version 3 of the License, or
+#   (at your option) any later version.
+#   
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#   
+#   You should have received a copy of the GNU General Public License
+#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # 
-# $Id: AppleEvents.tcl,v 1.5 2004/11/30 15:11:10 matben Exp $
+# $Id: AppleEvents.tcl,v 1.14 2008-05-26 09:41:58 matben Exp $
 
-namespace eval ::AppleEvents:: { }
-
-proc ::AppleEvents::Init { } {
-    global  this
-
-    if {![string equal $this(platform) "macosx"]} {
-	return
-    }
-    if {[catch {package require tclAE}]} {
-	return
-    }
-    ::Debug 2 "::AppleEvents::Init"
+namespace eval ::AppleEvents {
     
+    if {![string equal $::this(platform) "macosx"]} {
+	return
+    }
+    if {[catch {package require tclAE 2.0.3}]} {
+	return
+    }
+    component::define AppleEvents "Apple event handlers for Launch Services."
+}
+
+proc ::AppleEvents::Init {} {
+
+    ::Debug 2 "::AppleEvents::Init"    
  
     #tclAE::installEventHandler aevt GURL ::AppleEvents::HandleGURL
 
@@ -32,8 +48,22 @@ proc ::AppleEvents::Init { } {
     # test...
     tclAE::installEventHandler WWW! OURL ::AppleEvents::HandleOURL
     
-    component::register AppleEvents  \
-      {Apple event handlers for Launch Services.}
+    component::register AppleEvents
+}
+
+# AppleEvents::WhenLaunched --
+#
+#       This is a method to invoke handlers *after* we have launched.
+
+proc ::AppleEvents::WhenLaunched {cmd event reply} {
+    global  state
+    
+    if {[info exists state(launchStatus)]} {
+	::hooks::register afterFinalHook \
+	  [list ::AppleEvents::WhenLaunched $cmd $event $reply]
+    } else {
+	uplevel #0 $cmd [list $event $reply]
+    }
 }
 
 proc ::AppleEvents::HandleOURL {theAppleEvent theReplyAE} {
@@ -44,9 +74,15 @@ proc ::AppleEvents::HandleOURL {theAppleEvent theReplyAE} {
 }
 
 proc ::AppleEvents::OpenAppHandler {theAppleEvent theReplyAE} {
+    WhenLaunched ::AppleEvents::OpenApp $theAppleEvent $theReplyAE
+}
+
+proc ::AppleEvents::OpenApp {theAppleEvent theReplyAE} {
 
     # Have no idea of what to do here...
-    ::Debug 4 "::AppleEvents::OpenAppHandler theAppleEvent=$theAppleEvent"
+    ::Debug 4 "::AppleEvents::OpenApp theAppleEvent=$theAppleEvent"
+    return
+    
     set eventClass [tclAE::getAttributeData $theAppleEvent evcl]
     set eventID [tclAE::getAttributeData $theAppleEvent evid]
     ::Debug 4 "\t eventClass=$eventClass, eventID=$eventID"
@@ -55,8 +91,12 @@ proc ::AppleEvents::OpenAppHandler {theAppleEvent theReplyAE} {
 }
 
 proc ::AppleEvents::OpenHandler {theAppleEvent theReplyAE} {
+    WhenLaunched ::AppleEvents::Open $theAppleEvent $theReplyAE
+}
 
-    ::Debug 4 "::AppleEvents::OpenHandler theAppleEvent=$theAppleEvent"
+proc ::AppleEvents::Open {theAppleEvent theReplyAE} {
+
+    ::Debug 4 "::AppleEvents::Open theAppleEvent=$theAppleEvent"
     set pathDesc [tclAE::getKeyDesc $theAppleEvent ----]
     set paths [ExtractPaths $pathDesc wasList]
     tclAE::disposeDesc $pathDesc
@@ -72,6 +112,10 @@ proc ::AppleEvents::OpenHandler {theAppleEvent theReplyAE} {
 }
 
 proc ::AppleEvents::PrintHandler {theAppleEvent theReplyAE} {
+    WhenLaunched ::AppleEvents::Print $theAppleEvent $theReplyAE
+}
+
+proc ::AppleEvents::Print {theAppleEvent theReplyAE} {
 
     set pathDesc [tclAE::getKeyDesc $theAppleEvent ----]
     set paths [ExtractPaths $pathDesc wasList]
@@ -80,8 +124,9 @@ proc ::AppleEvents::PrintHandler {theAppleEvent theReplyAE} {
     foreach f $paths {	
 	switch -- [file extension $f] {
 	    .can {
-		set wtop [::WB::NewWhiteboard -file $f]
-		::UserActions::DoPrintCanvas $wtop
+		set w [::WB::NewWhiteboard -file $f]
+		set wcan [::WB::GetCanvasFromWtop $w]
+		::UserActions::DoPrintCanvas $wcan
 	    }
 	}
     }
@@ -102,7 +147,7 @@ proc ::AppleEvents::QuitHandler {theAppleEvent theReplyAE} {
 
 proc ::AppleEvents::ExtractPaths {files {wasList ""}} {
     
-    set paths {}
+    set paths [list]
     upvar 1 $wasList listOfPaths
     
     switch -- [tclAE::getDescType $files] {
