@@ -40,6 +40,7 @@ proc ::BuddyPounce::Init {} {
     
     # Add all hooks we need.
     ::hooks::register quitAppHook              ::BuddyPounce::QuitHook
+    ::hooks::register logoutHook               ::BuddyPounce::LogoutHook
     ::hooks::register newMessageHook           ::BuddyPounce::NewMsgHook
     ::hooks::register newChatMessageHook       ::BuddyPounce::NewChatMsgHook
     ::hooks::register presenceHook             ::BuddyPounce::PresenceHook    
@@ -80,6 +81,9 @@ proc ::BuddyPounce::Init {} {
     
     # And for 'any' which is not an array.
     variable budprefsany {}
+
+    # To save thread Id seen already, and to lookup on subsequent messages
+    variable threadids
         
     variable alertTitle 
     array set alertTitle {
@@ -126,7 +130,7 @@ proc ::BuddyPounce::Build {typeselected item groupL} {
     ::Debug 2 "::BuddyPounce::Build typeselected=$typeselected, item=$item, groupL=$groupL"
 
     # Initialize the state variable, an array, that keeps is the storage.
-    set uid [join [split [jlib::barejid $item] "@."] ""]
+    set uid [join [split [jlib::barejid $item] "@. "] ""]
     set token [namespace current]::$uid
     variable $token
     upvar 0 $token state
@@ -230,7 +234,6 @@ proc ::BuddyPounce::Build {typeselected item groupL} {
     foreach estr $events(str) ekey $events(keys) {
 
 	$wnb add [ttk::frame $wnb.$ekey] -text [mc $estr] -sticky news
-		
 	# Action
 	set wact $wnb.$ekey.f
 	ttk::frame $wact -padding [option get . notebookPagePadding {}]
@@ -316,7 +319,7 @@ proc ::BuddyPounce::Build {typeselected item groupL} {
     # Trick to resize the labels wraplength.
     set script [format {
 	update idletasks
-	%s configure -wraplength [expr [winfo reqwidth %s] - 12]
+	%s configure -wraplength [expr {[winfo reqwidth %s] - 12}]
     } $wbox.msg $w]    
     after idle $script
 
@@ -567,7 +570,7 @@ proc ::BuddyPounce::Event {from eventkey args} {
     dict set budpounce available [mc "%s just went online!" $from]
     dict set budpounce unavailable [mc "%s just went offline!" $from]
     dict set budpounce msg [mc "%s just sent you a message!" $from]
-    dict set budpounce chat [mc "%s just started a chat!" $from]
+    dict set budpounce chat [mc "%s just started a chat session!" $from]
 
     foreach action $actions {
 	
@@ -640,6 +643,12 @@ proc ::BuddyPounce::QuitHook {} {
     ::UI::SaveWinPrefixGeom $wdlg
 }
 
+proc ::BuddyPounce::LogoutHook {} {
+    variable threadids
+
+    array unset threadids *
+}
+
 proc ::BuddyPounce::CloseHook {wclose} {
     variable wdlg
 
@@ -648,10 +657,29 @@ proc ::BuddyPounce::CloseHook {wclose} {
 }
 
 proc ::BuddyPounce::NewChatMsgHook {xmldata} {
+    variable threadids
 
     set from [wrapper::getattribute $xmldata from]
     set jid2 [jlib::barejid $from]
-    Event $jid2 chat -xmldata $xmldata
+    set msgChatState ""
+    # only in case a body is in the chat message, produce a chat 
+    # state notificaton, otherwise it would also trigger on chat
+    # state notifications from the other user
+    if {[wrapper::havechildtag $xmldata body]} {
+	# now check whether we already know this thread
+	# since we only want to trigger an event on thread start
+	set threadid [wrapper::getcdata [wrapper::getfirstchildwithtag $xmldata thread]]
+	if { $threadid ne "" } { 
+	    if {![info exists threadids($threadid)]} {
+		# we haven't seen the thread yet, lets save the ID
+		# and trigger an event
+		set threadids($threadid) $threadid
+                Event $jid2 chat -xmldata $xmldata
+	    }
+	} else {
+            Event $jid2 chat -xmldata $xmldata
+	}
+    }
 }
 
 proc ::BuddyPounce::NewMsgHook {xmldata uuid} {
