@@ -842,7 +842,7 @@ proc tileutils::configstyles {name} {
 proc tileutils::LoadImages {imgdir {patterns {*.gif}}} {
     variable tiles
     
-    foreach file [eval {glob -nocomplain -directory $imgdir} $patterns] {
+    foreach file [eval {glob -nocomplain -directory $imgdir} -- $patterns] {
 	set name [file tail [file rootname $file]]
 	if {![info exists tiles($name)]} {
 	    set ext [file extension $file]
@@ -1072,7 +1072,7 @@ proc ttk::optionmenuex {w varName args} {
     variable $w
     upvar #0 $w state
 
-    if {[expr [llength $args] % 2 == 1]} {
+    if {[expr {[llength $args}] % 2 == 1]} {
 	return -code "args must have an even number of elements"
     }
     set state(varName) $varName
