@@ -464,8 +464,8 @@ proc ::ttoolbar::Popup {w x y} {
     
     update idletasks
     
-    set X [expr [winfo rootx $w] + $x]
-    set Y [expr [winfo rooty $w] + $y]
+    set X [expr {[winfo rootx $w] + $x}]
+    set Y [expr {[winfo rooty $w] + $y}]
     tk_popup $m [expr {int($X) - 0}] [expr {int($Y) - 0}]   
     
     return -code break
@@ -632,7 +632,7 @@ proc ::ttoolbar::MinWidth {w} {
     foreach {key wtext} [array get widgets *,text] {
 	array set gridInfo [grid info $wtext]
 	if {[info exists gridInfo(-padx)]} {
-	    incr width [expr 2*$gridInfo(-padx)]
+	    incr width [expr {2*$gridInfo(-padx)}]
 	    incr width [winfo reqwidth $wtext]
 	}
     }
