@@ -68,7 +68,7 @@ if {0} {
     set f /Users/matben/Library/Preferences/Coccinella/History/mari@localhost-0.nxml
     set f /Users/matben/Desktop/mariShort.xml
     set f /Users/matben/Desktop/mari.xml
-    set age [expr [clock seconds] - [clock scan 20070124T14:17:54]]
+    set age [expr {[clock seconds] - [clock scan 20070124T14:17:54]}]
     ::History::XFastSelection $f 10 $age  
     
     ::History::XFastParseFiles mari@localhost 2 0
@@ -191,7 +191,7 @@ proc ::History::XGetAllNXMLFileNames {jid} {
     if {$jid ne ""} {
 	set mjid [jlib::jidmap $jid]
 	set rootTail [::uri::urn::quote $mjid]
-	set nfiles [glob -nocomplain -directory $this(historyPath) ${rootTail}-*.nxml]
+	set nfiles [glob -nocomplain -directory $this(historyPath) -- ${rootTail}-*.nxml]
 	return [lsort -dictionary $nfiles]
     }
     return
@@ -202,7 +202,7 @@ proc ::History::XGetAllXMLFileNames {jid} {
     
     set mjid [jlib::jidmap $jid]
     set rootTail [::uri::urn::quote $mjid]
-    set xfiles [glob -nocomplain -directory $this(historyPath) ${rootTail}-*.xml]
+    set xfiles [glob -nocomplain -directory $this(historyPath) -- ${rootTail}-*.xml]
     return [lsort -dictionary $xfiles]
 }
 
