@@ -305,6 +305,9 @@ namespace eval ::Jabber {
 	set ::config(caps,vers) "9.9"
 	set ::config(vers,full) "9.9"
     }
+
+    # the error messages stating connection problems will disappear after $errormessagetimeout
+    variable errormessagetimeout 10000
 }
 
 # If the whiteboard/ complete dir is there we get whiteboard support.
@@ -377,7 +380,7 @@ proc ::Jabber::FactoryDefaults {} {
       [lindex $jserver(profile) 0]
     
     #
-    set jprefs(urlServersList) "http://www.jabber.org/basicservers.xml"
+    set jprefs(urlServersList) "http://xmpp.org/services/services.xml"
         
     # Menu definitions for the Roster/services window. Collects minimal Jabber
     # stuff.
@@ -891,6 +894,7 @@ proc ::Jabber::ClientProc {jlibName what args} {
     global  wDlgs jprefs
     
     variable jstate
+    variable errormessagetimeout
     
     ::Debug 2 "::Jabber::ClientProc: jlibName=$jlibName, what=$what, args='$args'"
     
@@ -909,7 +913,9 @@ proc ::Jabber::ClientProc {jlibName what args} {
 	    # Disconnect. This should reset both wrapper and XML parser!
 	    #::Jabber::DoCloseClientConnection
 	    SetClosedState
-	    ui::dialog -icon error -title [mc "Error"] -type ok \
+	    # Added the arbitrary -timeout argument, necessary
+	    # to allow the start of ::Login::AutoReLogin mechanism.
+	    ui::dialog -icon error -title [mc "Error"] -type ok -timeout $errormessagetimeout \
 	      -message [mc "The connection was unexpectedly broken."]
 	}
 	streamerror - xmpp-streams-error* {
@@ -919,7 +925,7 @@ proc ::Jabber::ClientProc {jlibName what args} {
 	    } else {
 		set msg [mc "Received a fatal error: %s The connection is closed." ""]
 	    }
-	    ui::dialog -title [mc "Error"] -icon error -type ok -message $msg
+	    ui::dialog -title [mc "Error"] -icon error -type ok -timeout $errormessagetimeout -message $msg
 	}
 	xmlerror {
 	    
@@ -931,21 +937,27 @@ proc ::Jabber::ClientProc {jlibName what args} {
 	    } else {
 		set msg [mc "Received a fatal error: %s The connection is closed." ""]
 	    }
-	    ui::dialog -title [mc "Error"] -icon error -type ok -message $msg
+	    # Added the arbitrary -timeout argument, necessary
+	    # to allow the start of ::Login::AutoReLogin mechanism.
+	    ui::dialog -title [mc "Error"] -icon error -type ok -timeout $errormessagetimeout -message $msg
 	}
 	networkerror {
 	    
 	    # Disconnect. This should reset both wrapper and XML parser!
 	    #::Jabber::DoCloseClientConnection
-	    SetClosedState
+	    SetReconnectState
 	    set msg [mc "The connection was unexpectedly broken."]
 	    if {[info exists argsA(-errormsg)]} {
 		append msg "\n"
 		append msg $argsA(-errormsg)
 	    }
-	    ui::dialog -icon error -title [mc "Error"] -type ok -message $msg
+	    # Added the arbitrary -timeout argument, necessary
+	    # to allow the start of ::Login::AutoReLogin mechanism.
+	    ui::dialog -icon error -title [mc "Error"] -type ok -timeout $errormessagetimeout -message $msg
 	}
     }
+    # start the automatic relogin procedure
+    ::Login::AutoReLogin
     return $ishandled
 }
 
@@ -1089,7 +1101,6 @@ proc ::Jabber::DoCloseClientConnection {args} {
 
 proc ::Jabber::SetClosedState {} {
     variable jstate
-    
     ::Debug 2 "::Jabber::SetClosedState"
 
     # Ourself.
@@ -1107,6 +1118,11 @@ proc ::Jabber::SetClosedState {} {
     ::hooks::run logoutHook
 }
 
+proc ::Jabber::SetReconnectState {} {
+    SetClosedState
+    ::JUI::SetConnectState "reconnecting"
+}
+
 # Jabber::EndSession --
 #
 #       This is supposed to be called only when doing Quit.
@@ -1518,7 +1534,7 @@ proc ::Jabber::GetLastString {jid subiq} {
     } elseif {![string is integer -strict $attrArr(seconds)]} {
 	set str [mc "Cannot query %s's local time information." $ujid]
     } else {
-	set secs [expr [clock seconds] - $attrArr(seconds)]
+	set secs [expr {[clock seconds] - $attrArr(seconds)}]
 	set uptime [clock format $secs -format "%a %b %d %H:%M:%S %Y"]
 	if {[wrapper::getcdata $subiq] ne ""} {
 	    set msg [mc "Message"]
@@ -2049,7 +2065,7 @@ proc ::Jabber::OnMenuLogInOut {} {
 	connect - connectfin {
 	    DoCloseClientConnection
 	}
-	connectinit {
+	connectinit - reconnecting {
 	    ::Login::Reset
 	}
 	disconnect {
