@@ -619,7 +619,7 @@ proc ::RosterTree::NotifyDragReceive {T dragged target} {
     # put the popup menu below the mouse pointer
     set X [winfo pointerx $T]
     set Y [winfo pointery $T]
-    tk_popup $m [expr int($X) - 10] [expr int($Y) - 10]
+    tk_popup $m [expr {int($X) - 10}] [expr {int($Y) - 10}]
 }
 
 proc ::RosterTree::DnDCopyOrMoveContact {T action dragged targetgroup} {
@@ -936,7 +936,7 @@ proc ::RosterTree::BackgroundImageGetFile {suffL defaultFile} {
 	    foreach suff $suffL {
 		lappend pattern "roster$suff"
 	    }    
-	    set files [eval {glob -nocomplain -directory $this(backgroundsPath)} $pattern]
+	    set files [eval {glob -nocomplain -directory $this(backgroundsPath)} -- $pattern]
 	    set fileName [lindex $files 0]
 	}
     }    
