@@ -286,9 +286,9 @@ proc ::Search::TablePopup {w x y} {
 	update idletasks
 	
 	# Post popup menu.	
-	set X [expr [winfo rootx $w] + $x]
-	set Y [expr [winfo rooty $w] + $y]
-	tk_popup $m [expr int($X) - 10] [expr int($Y) - 10]   
+	set X [expr {[winfo rootx $w] + $x}]
+	set Y [expr {[winfo rooty $w] + $y}]
+	tk_popup $m [expr {int($X) - 10}] [expr {int($Y) - 10}]   
     }
 }
 
@@ -820,9 +820,9 @@ proc ::Search::ResultOnPopup {T x y} {
 	update idletasks
 	
 	# Post popup menu.
-	set X [expr [winfo rootx $T] + $x]
-	set Y [expr [winfo rooty $T] + $y]
-	tk_popup $m [expr int($X) - 10] [expr int($Y) - 10]   
+	set X [expr {[winfo rootx $T] + $x}]
+	set Y [expr {[winfo rooty $T] + $y}]
+	tk_popup $m [expr {int($X) - 10}] [expr {int($Y) - 10}]   
     }
     return -code break
 }
@@ -982,8 +982,8 @@ proc ::Search::SlotPopup {w x y} {
     
     update idletasks
     
-    set X [expr [winfo rootx $w] + $x]
-    set Y [expr [winfo rooty $w] + $y]
+    set X [expr {[winfo rootx $w] + $x}]
+    set Y [expr {[winfo rooty $w] + $y}]
     tk_popup $m [expr {int($X) - 0}] [expr {int($Y) - 0}]   
     
     return -code break
