@@ -169,7 +169,7 @@ proc ::Init::SetThis {mainScript} {
     
     # Need a tmp directory, typically in a StarKit when QuickTime movies are opened.
     set MAX_INT 0x7FFFFFFF
-    set hex [format {%x} [expr int($MAX_INT*rand())]]
+    set hex [format {%x} [expr {int($MAX_INT*rand())}]]
     set tail coccinella[pid]-$hex
     set this(tmpPath) [file join [TempDir] $tail]
     if {![file isdirectory $this(tmpPath)]} {
@@ -182,8 +182,11 @@ proc ::Init::SetThis {mainScript} {
 	if {[regexp {[2-9]86} $tcl_platform(machine)]} {
 	    set machine "i686"
 	} elseif {$tcl_platform(machine) eq "x86_64"} {
-	    # x86_64
-	    set machine "i686"
+	    if {[info exists ::starkit::topdir]} {
+	        set machine "i686"
+	    } else {
+	        set machine "x86_64"
+	    }
 	}
 	set machineSpecPath [file join $tcl_platform(os) $machine]
     } elseif {$this(platform) eq "macosx"} {
@@ -409,6 +412,7 @@ proc ::Init::SetPrefsPaths {} {
     set this(recentAvatarPath)  [file join $path avatar recent]
     set this(scriptsPath)       [file join $path scripts]
     set this(backgroundsPath)   [file join $path backgrounds]
+    set this(certificatesPath)  [file join $path certificates]
 
     set pname $this(prefsName)
 
@@ -494,7 +498,7 @@ proc ::Init::SetThisVersion {} {
     # default file, never read.
     set this(vers,major)    0
     set this(vers,minor)   96
-    set this(vers,release)  18
+    set this(vers,release)  20
     
     # NB: The 'minorRelease' number is only used for released versions and not
     #     in cvs or so called daily builds. cvs always have odd 'release'
@@ -622,7 +626,7 @@ proc ::Init::Msgcat {} {
 
     set this(systemLocale) $locale
     set lang [lindex [split [file rootname $locale] _] 0]
-    set langs [glob -nocomplain -tails -directory $this(msgcatPath) *.msg]
+    set langs [glob -nocomplain -tails -directory $this(msgcatPath) -- *.msg]
     set havecat 0
     foreach f $langs {
 	set langcode [lindex [split [file rootname $f] _] 0]
@@ -762,6 +766,8 @@ proc ::Init::LoadPackages {} {
 	::Splash::SetMsg [mc "Looking for %s" $name]...
 	if {![catch {package require $name} msg]} {
 	    set this(package,$name) 1
+	} else {
+	    ::Debug 2 "unable to load package: $name, reason: $msg"
 	}
     }
     if {$this(package,Itcl)} {
