@@ -180,7 +180,7 @@ proc ::Network::ScheduleKiller {sock cmd} {
     if {[info exists killerId($sock)]} {
 	after cancel $killerId($sock)
     }
-    set killerId($sock) [after [expr 1000 * $opts(-timeout)]   \
+    set killerId($sock) [after [expr {1000 * $opts(-timeout)}]   \
       [list [namespace current]::Kill $sock $cmd]]
 }
 
