@@ -5,11 +5,24 @@
 #       mime type <-> file suffix
 #       mac type <-> file suffix
 #      
-#  Copyright (c) 2003-2004  Mats Bengtsson
+#  Copyright (c) 2003-2005  Mats Bengtsson
+#  
+#   This program is free software: you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation, either version 3 of the License, or
+#   (at your option) any later version.
+#   
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#   
+#   You should have received a copy of the GNU General Public License
+#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #  
 #  See the README file for license, bugs etc.
 #  
-# $Id: Types.tcl,v 1.11 2004/07/30 12:55:55 matben Exp $
+# $Id: Types.tcl,v 1.20 2007-09-14 08:11:47 matben Exp $
 
 package provide Types 1.0
 
@@ -73,6 +86,7 @@ namespace eval ::Types:: {
 	text/html            {.html .htm}
 	text/richtext        {.rtx}
 	text/xml             {.xml}
+	text/css             {.css}
 	video/quicktime      {.mov  .qt}
 	video/mpeg4          {.mp4}
 	video/x-msvideo      {.avi}
@@ -88,62 +102,63 @@ namespace eval ::Types:: {
     variable mime2Desc
     array set mime2Desc {
 	application/x-world  {World Application}
-	application/x-3dmf   {3D Meta Format}
-	application/x-tcl    {Tcl Application}
-	application/x-itcl   {Itcl Application}
+	application/x-3dmf   {QuickDraw 3D Metafile}
+	application/x-tcl    {Tcl File}
+	application/x-itcl   {Itcl File}
 	application/sdp      {Session Description Protocol}
-	application/x-shockwave-flash  {Shockwave Flash}
+	application/x-shockwave-flash  {Adobe Flash Media}
 	application/macbinary {Mac Binary}
 	application/x-macbinary {Mac Binary}
 	application/vtk      {VTK 3D}
-	application/octet-stream {Generic Type}
-	application/pdf      {Portable Document Format}
-	application/postscript {Postscript Document}
-	application/rtf      {Rich Text Format}
-	application/x-javascript {Java Script}
-	application/x-tex    {TeX Document}
-	application/x-tar    {Tape Archive}
+	application/octet-stream {Generic File}
+	application/pdf      {PDF Document}
+	application/postscript {PostScript Document}
+	application/rtf      {RTF Document}
+	application/x-javascript {JavaScript File}
+	application/x-tex    {TeX File}
+	application/x-tar    {Archive Tar}
 	application/abiword  {Abi Word Document}
-	application/vnd.ms-excel {MS Excel Document}
-	application/vnd.ms-powerpoint {PowerPoint Slide Show}
-	application/msword   {Word Document}
+	application/vnd.ms-excel {Microsoft Excel Spreadsheet}
+	application/vnd.ms-powerpoint {Microsoft PowerPoint Presentation}
+	application/msword   {Microsoft Word Document}
 	audio/mpeg           {MPEG Audio}
 	audio/x-mpeg         {MPEG Audio}
-	audio/aiff           {AIFF Audio}
-	audio/x-aiff         {AIFF Audio}
-	audio/basic          {ULAW Audio}
+	audio/aiff           {AIFF/Amiga Audio}
+	audio/x-aiff         {AIFF/Amiga Audio}
+	audio/basic          {ULAW (Sun) Audio}
 	audio/x-sd2          {Streaming Audio}
 	audio/wav            {WAV Audio}
 	audio/x-wav          {WAV Audio}
 	audio/vnd.qcelp      {QCP Audio}
 	audio/midi           {MIDI Audio}
 	audio/x-midi         {MIDI Audio}
-	image/x-bmp          {Windows BMP Image}
-	image/vnd.fpx        {Image}
+	image/x-bmp          {BMP Image}
+	image/vnd.fpx        {FlashPix Image}
 	image/gif            {GIF Image}
 	image/jpeg           {JPEG Image}
 	image/x-macpaint     {Macpaint Image}
-	image/x-photoshop    {Photoshop Image}
+	image/x-photoshop    {Adobe Photoshop Image}
 	image/png            {PNG Image}
 	image/x-png          {PNG Image}
 	image/pict           {PICT Image}
 	image/x-sgi          {SGI Image}
-	image/x-targa        {Targa Truevision Image}
+	image/x-targa        {Truevision Targa Image}
 	image/tiff           {TIFF Image}
 	image/x-tiff         {TIFF Image}
-	image/x-portable-pixmap {Portable Pixmap}
-	text/plain           {Plain Text}
-	text/xml             {Extensible Markup Language}
-	text/richtext        {Rich Text Format}
-	text/html            {Hypertext Markup Language}
+	image/x-portable-pixmap {X PixMap Image}
+	text/plain           {Plain Text Document}
+	text/xml             {XML Document}
+	text/richtext        {RTF Document}
+	text/html            {HTML Document}
+	text/css             {Cascading Style Sheet}
 	video/quicktime      {QuickTime Video}
-	video/mpeg4          {MPEG 4 Video}
+	video/mpeg4          {MPEG-4 Video}
 	video/x-dv           {DV Video}
 	video/mpeg           {MPEG Video}
-	video/x-mpeg         {MPEG Video and Audio}
-	video/x-msvideo      {Microsoft Video}
-	video/avi            {Microsoft Video}
-	video/flc            {FLC Animation}
+	video/x-mpeg         {MPEG Video}
+	video/x-msvideo      {Microsoft AVI Video}
+	video/avi            {Microsoft AVI Video}
+	video/flc            {Autodesk's FLIC File}
     }
     
     
@@ -233,9 +248,9 @@ namespace eval ::Types:: {
     }
 }
 
-# ::Types::Init --
+# Types::Init --
 
-proc ::Types::Init { } {
+proc ::Types::Init {} {
     variable mime2SuffList
     variable mime2MacTypeList
     variable suff2MimeList
@@ -284,7 +299,7 @@ proc ::Types::Init { } {
 #       Checks that we haven't missed something when setting up our arrays.
 #       Is always run "offline".
 
-proc ::Types::QuickCheck { } {
+proc ::Types::QuickCheck {} {
     variable mime2SuffList
     variable mime2Desc
     variable mime2MacTypeList
@@ -292,7 +307,7 @@ proc ::Types::QuickCheck { } {
     variable suff2MacType
  
     set allSuffs {}
-    foreach m [::Types::GetAllMime] {
+    foreach m [GetAllMime] {
 	if {![info exists mime2SuffList($m)]} {
 	    puts "$m\t\tmissing mime2SuffList"
 	} else {
@@ -322,7 +337,7 @@ proc ::Types::QuickCheck { } {
 #       default values are filled in. Typically run after getting preferences
 #       to stop any corruption.
 
-proc ::Types::VerifyInternal { } {
+proc ::Types::VerifyInternal {} {
     variable mime2SuffList
     variable mime2Desc
     variable mime2MacTypeList
@@ -330,7 +345,7 @@ proc ::Types::VerifyInternal { } {
     variable suff2MacType
     
     set allSuffs {}
-    foreach m [::Types::GetAllMime] {
+    foreach m [GetAllMime] {
 	if {![info exists mime2SuffList($m)]} {
 	    set mime2SuffList($m) {}
 	}
@@ -372,14 +387,17 @@ proc ::Types::GetMimeTypeForFileName {fileName} {
     variable inited
     
     if {!$inited} {
-	::Types::Init
+	Init
     }    
     set fext [string tolower [file extension $fileName]]
     if {[string equal $this(platform) "macintosh"]} {
 	set mime [GetMimeTypeForMacFile $fileName]
     } else {
 	if {[info exists suff2MimeList($fext)]} {
+	    
+	    # Remove any extra ../x-..
 	    set mime [lindex $suff2MimeList($fext) 0]
+	    set mime [regsub {x-} $mime {}]
 	} else {
 	    set mime application/octet-stream
 	}
@@ -404,7 +422,7 @@ proc ::Types::GetMimeTypeForMacFile {fileName} {
     variable inited
 
     if {!$inited} {
-	::Types::Init
+	Init
     }    
     set fext [string tolower [file extension $fileName]]
     if {[string length $fext]}  {
@@ -484,7 +502,7 @@ proc ::Types::GetFileTailAddSuffix {filePath} {
     set fileTail [file tail $filePath]
     if {[string equal $this(platform) "macintosh"]} {
 	set fext [file extension $fileTail]
-	if {$fext == ""} {
+	if {$fext eq ""} {
 	    set fileTailSuff "${fileTail}[GetSuffixForMacFile $filePath]"
 	} else {
 	    set fileTailSuff $fileTail
@@ -505,7 +523,7 @@ proc ::Types::GetSuffixListForMime {mime} {
     if {[info exists mime2SuffList($mime)]} {
 	return $mime2SuffList($mime)
     } else {
-	return ""
+	return
     }
 }
 
@@ -515,7 +533,18 @@ proc ::Types::SetSuffixListForMime {mime suffList} {
     set mime2SuffList($mime) $suffList
 }
 
-proc ::Types::GetSuffixListArr { } {
+proc ::Types::GetSuffixListForMimeList {mimeL} {
+    variable mime2SuffList
+    set suffL [list]
+    foreach mime $mimeL {
+	if {[info exists mime2SuffList($mime)]} {
+	    set suffL [concat $suffL $mime2SuffList($mime)]
+	}
+    }
+    return [lsort -unique $suffL]
+}
+
+proc ::Types::GetSuffixListArr {} {
     variable mime2SuffList
 
     return [array get mime2SuffList]
@@ -535,17 +564,70 @@ proc ::Types::GetMacTypeListForMime {mime} {
     if {[info exists mime2MacTypeList($mime)]} {
 	return $mime2MacTypeList($mime)
     } else {
-	return ""
+	return
     }
 }
 
 proc ::Types::GetDescriptionForMime {mime} {
     variable mime2Desc
 
+    # Ugly hack to make xgettext find these strings; Mats should make this nicier
+    variable mimeText
+    set mimeText [dict create]
+    dict set mimeText "World Application" [mc "World Application"]
+    dict set mimeText "QuickDraw 3D Metafile" [mc "QuickDraw 3D Metafile"]
+    dict set mimeText "Tcl File" [mc "Tcl File"]
+    dict set mimeText "Itcl File" [mc "Itcl File"]
+    dict set mimeText "Session Description Protocol" [mc "Session Description Protocol"]
+    dict set mimeText "Adobe Flash Media" [mc "Adobe Flash Media"]
+    dict set mimeText "Mac Binary" [mc "Mac Binary"]
+    dict set mimeText "VTK 3D" [mc "VTK 3D"]
+    dict set mimeText "Generic File" [mc "Generic File"]
+    dict set mimeText "PDF Document" [mc "PDF Document"]
+    dict set mimeText "PostScript Document" [mc "PostScript Document"]
+    dict set mimeText "RTF Document" [mc "RTF Document"]
+    dict set mimeText "JavaScript File" [mc "JavaScript File"]
+    dict set mimeText "TeX File" [mc "TeX File"]
+    dict set mimeText "Archive Tar" [mc "Archive Tar"]
+    dict set mimeText "Abi Word Document" [mc "Abi Word Document"]
+    dict set mimeText "Microsoft Excel Spreadsheet" [mc "Microsoft Excel Spreadsheet"]
+    dict set mimeText "Microsoft PowerPoint Presentation" [mc "Microsoft PowerPoint Presentation"]
+    dict set mimeText "Microsoft Word Document" [mc "Microsoft Word Document"]
+    dict set mimeText "MPEG Audio" [mc "MPEG Audio"]
+    dict set mimeText "AIFF/Amiga Audio" [mc "AIFF/Amiga Audio"]
+    dict set mimeText "ULAW (Sun) Audio" [mc "ULAW (Sun) Audio"]
+    dict set mimeText "Streaming Audio" [mc "Streaming Audio"]
+    dict set mimeText "WAV Audio" [mc "WAV Audio"]
+    dict set mimeText "QCP Audio" [mc "QCP Audio"]
+    dict set mimeText "MIDI Audio" [mc "MIDI Audio"]
+    dict set mimeText "BMP Image" [mc "BMP Image"]
+    dict set mimeText "FlashPix Image" [mc "FlashPix Image"]
+    dict set mimeText "GIF Image" [mc "GIF Image"]
+    dict set mimeText "JPEG Image" [mc "JPEG Image"]
+    dict set mimeText "Macpaint Image" [mc "Macpaint Image"]
+    dict set mimeText "Adobe Photoshop Image" [mc "Adobe Photoshop Image"]
+    dict set mimeText "PNG Image" [mc "PNG Image"]
+    dict set mimeText "PICT Image" [mc "PICT Image"]
+    dict set mimeText "SGI Image" [mc "SGI Image"]
+    dict set mimeText "Truevision Targa Image" [mc "Truevision Targa Image"]
+    dict set mimeText "TIFF Image" [mc "TIFF Image"]
+    dict set mimeText "X PixMap Image" [mc "X PixMap Image"]
+    dict set mimeText "Plain Text Document" [mc "Plain Text Document"]
+    dict set mimeText "XML Document" [mc "XML Document"]
+    dict set mimeText "RTF Document" [mc "RTF Document"]
+    dict set mimeText "HTML Document" [mc "HTML Document"]
+    dict set mimeText "Cascading Style Sheet" [mc "Cascading Style Sheet"]
+    dict set mimeText "QuickTime Video" [mc "QuickTime Video"]
+    dict set mimeText "MPEG-4 Video" [mc "MPEG-4 Video"]
+    dict set mimeText "DV Video" [mc "DV Video"]
+    dict set mimeText "MPEG Video" [mc "MPEG Video"]
+    dict set mimeText "Microsoft AVI Video" [mc "Microsoft AVI Video"]
+    dict set mimeText "Autodesk's FLIC File" [mc "Autodesk's FLIC File"]
+
     if {[info exists mime2Desc($mime)]} {
-	return $mime2Desc($mime)
+	return [dict get $mimeText $mime2Desc($mime)]
     } else {
-	return ""
+	return $mime
     }
 }
 
@@ -555,7 +637,7 @@ proc ::Types::SetDescriptionForMime {mime desc} {
     set mime2Desc($mime) $desc
 }
 
-proc ::Types::GetDescriptionArr { } {
+proc ::Types::GetDescriptionArr {} {
     variable mime2Desc
 
     return [array get mime2Desc]
@@ -569,13 +651,13 @@ proc ::Types::SetDescriptionArr {descListName} {
     array set mime2Desc [array get locArrName]
 }
 
-proc ::Types::GetAllMime { } {
+proc ::Types::GetAllMime {} {
     variable mime2SuffList
     
     return [array names mime2SuffList]
 }
 
-proc ::Types::GetSuffMimeArr { } {
+proc ::Types::GetSuffMimeArr {} {
     variable prefSuff2MimeType
     
     return [array get prefSuff2MimeType]
@@ -601,7 +683,7 @@ proc ::Types::SetMimeTextOrNot {mime what} {
     set mimeIsText($mime) $what
 }
 
-proc ::Types::GetIsMimeTextArr { } {
+proc ::Types::GetIsMimeTextArr {} {
     variable mimeIsText
 
     return [array get mimeIsText]
