@@ -8,11 +8,22 @@
 #           
 #       It also contains support functions for adding external plugins.
 #      
-#  Copyright (c) 2003-2004  Mats Bengtsson
+#  Copyright (c) 2003-2008  Mats Bengtsson
 #  
-#  See the README file for license, bugs etc.
+#   This program is free software: you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation, either version 3 of the License, or
+#   (at your option) any later version.
+#   
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#   
+#   You should have received a copy of the GNU General Public License
+#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #  
-# $Id: Plugins.tcl,v 1.15 2004/12/08 08:21:20 matben Exp $
+# $Id: Plugins.tcl,v 1.37 2008-05-22 08:11:03 matben Exp $
 #
 # We need to be very systematic here to handle all possible MIME types
 # and extensions supported by each package or helper application.
@@ -25,7 +36,7 @@
 #                    It contains a bin (binary) element as well which is the
 #                    the union of all MIME types except text.
 #                    This should only be used internally to compile the
-#                    dialog -typelist values.
+#                    dialog -filetypes values.
 #                    
 # supportedMimeTypes: maps package name to supported MIME types for that package,
 #                    and maps from MIME type (image, audio, video) to MIME type.
@@ -73,23 +84,29 @@
 #  
 #-------------------------------------------------------------------------------
 
-package provide Plugins 1.0
+# @@@ TODO: try to use as much from Media as possible.
 
+package require Media
 package require Types
 
-namespace eval ::Plugins:: {
+package provide Plugins 1.0
+
+namespace eval ::Plugins {
     global tcl_platform
     
-    # Define all hooks for preference settings. Be early!
-    ::hooks::register prefsInitHook          ::Plugins::InitPrefsHook     10
+    # Define all hooks for preference settings.
+    # We init as late as possible.
+    # Make sure we are inited before showing any prefs panels.
+    ::hooks::register afterFinalHook         ::Plugins::InitPrefsHook
+    ::hooks::register prefsBuildHook         ::Plugins::BuildInitPrefsHook 10
     ::hooks::register prefsBuildHook         ::Plugins::BuildPrefsHook
     ::hooks::register prefsUserDefaultsHook  ::Plugins::UserDefaultsHook
     ::hooks::register prefsSaveHook          ::Plugins::SaveHook
     ::hooks::register prefsCancelHook        ::Plugins::CancelHook
     ::hooks::register prefsDestroyHook       ::Plugins::DestroyPrefsHook
-    ::hooks::register initHook               ::Plugins::InitHook
 
     variable inited 0
+    
     variable packages2Platform
     variable helpers2Platform
     variable supSuff
@@ -100,25 +117,25 @@ namespace eval ::Plugins:: {
     # Supported binary files, that is, images movies etc.
     # Start with the core Tk supported formats. Mac 'TYPE'.
     set plugin(tk,loaded) 1
-    set supSuff(text) {.txt}
-    set supSuff(image) {}
-    set supSuff(audio) {}
-    set supSuff(video) {}
-    set supSuff(application) {}
+    set supSuff(text)  {.txt}
+    set supSuff(image) [list]
+    set supSuff(audio) [list]
+    set supSuff(video) [list]
+    set supSuff(application) [list]
 
-    set supMacTypes(text) {TEXT}
-    set supMacTypes(image) {}
-    set supMacTypes(audio) {}
-    set supMacTypes(video) {}
-    set supMacTypes(application) {}
+    set supMacTypes(text)  {TEXT}
+    set supMacTypes(image) [list]
+    set supMacTypes(audio) [list]
+    set supMacTypes(video) [list]
+    set supMacTypes(application) [list]
 
     # Map keywords and package names to the supported MIME types.
     # Start by initing, MIME types added below.
-    set supportedMimeTypes(text) text/plain
-    set supportedMimeTypes(image) {}
-    set supportedMimeTypes(audio) {}
-    set supportedMimeTypes(video) {}
-    set supportedMimeTypes(application) {}
+    set supportedMimeTypes(text)  text/plain
+    set supportedMimeTypes(image) [list]
+    set supportedMimeTypes(audio) [list]
+    set supportedMimeTypes(video) [list]
+    set supportedMimeTypes(application) [list]
     set supportedMimeTypes(all) $supportedMimeTypes(text)
     
     # Search only for packages on platforms they can live on.
@@ -126,16 +143,10 @@ namespace eval ::Plugins:: {
 	QuickTimeTcl       {            macosx    windows} 
 	snack              {windows     unix}
 	Img                {windows     unix}
+	tkpng              {macosx      windows     unix}
     }
     array set helpers2Platform {xanim unix} 
-    
-    # Snack buggy on NT4.
-    if {($tcl_platform(os) == "Windows NT") &&  \
-      ($tcl_platform(osVersion) == 4.0)} {
-	set packages2Platform(snack)  \
-	  [lsearch -inline -not -all $packages2Platform(snack) "windows"]
-    }
-    
+        
     array set plugType2DescArr {
 	internal    "Internal Plugin"
 	external    "External Plugin"
@@ -143,26 +154,61 @@ namespace eval ::Plugins:: {
     }
     
     # Plugin ban list. Do not load these packages.
-    variable pluginBanList {}
+    variable pluginBanList [list]
 }
 
-# Plugins::Init --
+# Plugins::InitPrefsHook --
+#
+#       Handles all initializations. 
+#       We may call this any time to make sure it is inited.
+
+proc ::Plugins::InitPrefsHook {} {
+    global  prefs
+    variable inited
+
+    if {$inited} { return }
+
+    # Plugin ban list. Do not load these packages.
+    set prefs(pluginBanList) [list]
+    ::Debug 2 "::Plugins::InitPrefsHook"
+    
+    ::PrefUtils::Add [list  \
+      [list prefs(pluginBanList)   prefs_pluginBanList   $prefs(pluginBanList)]]
+    
+    # Load all plugins available.
+    SetBanList $prefs(pluginBanList)
+    InitAndLoad
+    
+    # Make sure the settings are consistent with the available packages.
+    VerifyPackagesForMimeTypes
+    if {[HavePackage QuickTimeTcl]} {
+	QuickTimeTclInitHook
+    }
+    
+    ::Debug 2 "--> whiteboardPrefsInitHook"
+    ::hooks::run whiteboardPrefsInitHook
+    
+    set inited 1
+}
+
+proc ::Plugins::BuildInitPrefsHook {wtree nbframe} {
+    InitPrefsHook
+}
+
+# Plugins::InitAndLoad --
 # 
 #       The initialization function which loads all plugins available.
 #       
 
-proc ::Plugins::Init { } {
+proc ::Plugins::InitAndLoad {} {
     global this
     variable mimeTypeDoWhat
-    variable packages2Platform
-    variable supportedMimeTypes
     variable prefMimeType2Package
     variable supSuff
     variable supMacTypes
     variable plugin
-    variable inited
     
-    ::Debug 2 "::Plugins::Init"
+    ::Debug 2 "::Plugins::InitAndLoad"
     
     foreach mime [::Types::GetAllMime] {
 	set mimeTypeDoWhat($mime) "unavailable"
@@ -170,47 +216,44 @@ proc ::Plugins::Init { } {
     }
     
     # Init the "standard" (internal and application) plugins.
-    ::Plugins::InitTk
-    ::Plugins::InitQuickTimeTcl
-    ::Plugins::InitSnack
-    ::Plugins::InitImg
-    ::Plugins::InitXanim
+    InitTk
+    InitQuickTimeTcl
+    InitSnack
+    InitImg
+    InitTkPNG
+    InitXanim
     
     # Load all "external" plugins.
     set pluginDir [file join $this(path) plugins]
-    ::Plugins::LoadPluginDirectory $pluginDir
+    LoadPluginDirectory $pluginDir
     
     # Load all packages and plugins we can.
-    ::Plugins::CompileAndLoadPackages
+    CompileAndLoadPackages
     
     # Set up various arrays used internally.
-    ::Plugins::PostProcessInfo
+    PostProcessInfo
     
     # This must be done after all plugins identified and loaded.
-    ::Plugins::MakeTypeListDialogOption
-    
-    set inited 1
+    MakeTypeListDialogOption
 }
 
-proc ::Plugins::InitTk { } {
+proc ::Plugins::InitTk {} {
     global this
     variable plugin
     variable supportedMimeTypes
-    variable packages2Platform
     variable supSuff
 
     set plugin(tk,type) "internal"
     set plugin(tk,desc) "Supported by the core"
     set plugin(tk,ver) [info tclversion]
     set plugin(tk,importProc) ::Import::DrawImage
-    set plugin(tk,icon,12) [image create photo -format gif -file \
-      [file join $this(imagePath) tklogo12.gif]]
+    set plugin(tk,icon,12) [::Theme::FindIcon mime/12x12/application-x-tcl]
     #set supSuff(tk) {.gif}
     set supportedMimeTypes(tk) {image/gif image/x-portable-pixmap}
     set plugin(tk,mimes) $supportedMimeTypes(tk)
 }
 
-proc ::Plugins::InitQuickTimeTcl { } {
+proc ::Plugins::InitQuickTimeTcl {} {
     global this
     variable plugin
     variable supportedMimeTypes
@@ -230,10 +273,10 @@ proc ::Plugins::InitQuickTimeTcl { } {
     set plugin(QuickTimeTcl,trpt,video) http
     
     # Define any 16x16 icon to spice up the UI.
-    set plugin(QuickTimeTcl,icon,16) [image create photo -format gif -file \
-      [file join $this(imagePath) qtlogo16.gif]]
-    set plugin(QuickTimeTcl,icon,12) [image create photo -format gif -file \
-      [file join $this(imagePath) qtlogo12.gif]]
+    set plugin(QuickTimeTcl,icon,16) \
+      [::Theme::FindIcon mime/16x16/video-quicktime]
+    set plugin(QuickTimeTcl,icon,12) \
+      [::Theme::FindIcon mime/12x12/video-quicktime]
     
     # We must list supported MIME types for each package.
     # For QuickTime:
@@ -259,7 +302,7 @@ proc ::Plugins::InitQuickTimeTcl { } {
 # On Unix/Linux and Windows we try to find the Snack Sound extension.
 # Only the "sound" part of the extension is actually needed.
 
-proc ::Plugins::InitSnack { } {
+proc ::Plugins::InitSnack {} {
     variable plugin
     variable supportedMimeTypes
     variable packages2Platform
@@ -281,7 +324,7 @@ proc ::Plugins::InitSnack { } {
 #--- Img -----------------------------------------------------------------------
 # The Img extension for reading more image formats than the standard one (gif).
 
-proc ::Plugins::InitImg { } {
+proc ::Plugins::InitImg {} {
     variable plugin
     variable supportedMimeTypes
     variable packages2Platform
@@ -299,13 +342,28 @@ proc ::Plugins::InitImg { } {
     set plugin(Img,mimes) $supportedMimeTypes(Img)
 }
 
-#--- xanim ---------------------------------------------------------------------
-# Test the 'xanim' app on Unix/Linux for multimedia.
-  
-proc ::Plugins::InitXanim { } {
+proc ::Plugins::InitTkPNG {} {
     variable plugin
     variable supportedMimeTypes
     variable packages2Platform
+    
+    set plugin(tkpng,pack) "tkpng"
+    set plugin(tkpng,type) "internal"
+    set plugin(tkpng,desc) "Adds png image support."
+    set plugin(tkpng,platform) $packages2Platform(tkpng)
+    set plugin(tkpng,importProc) ::Import::DrawImage
+    set supportedMimeTypes(tkpng) {
+	image/png           image/x-png
+    }
+    set plugin(tkpng,mimes) $supportedMimeTypes(tkpng)
+}
+
+#--- xanim ---------------------------------------------------------------------
+# Test the 'xanim' app on Unix/Linux for multimedia.
+  
+proc ::Plugins::InitXanim {} {
+    variable plugin
+    variable supportedMimeTypes
 
     set plugin(xanim,type) "application"
     set plugin(xanim,desc) "A unix/Linux only application that is used\
@@ -334,20 +392,20 @@ proc ::Plugins::SetBanList {banList} {
 #       Compile information of all packages and helper apps to search for.
 #       Do 'package require' and record any success.
 
-proc ::Plugins::CompileAndLoadPackages { } {
+proc ::Plugins::CompileAndLoadPackages {} {
     global this
     variable plugin
     variable pluginBanList
     
-    set plugin(all) {}
-    set plugin(allPacks) {}
-    set plugin(allHelpers) {}
+    set plugin(all) [list]
+    set plugin(allPacks) [list]
+    set plugin(allHelpers) [list]
 
-    set plugin(all) {}
-    set plugin(allPacks) {}
-    set plugin(allInternalPacks) {}
-    set plugin(allExternalPacks) {}
-    set plugin(allApps) {}
+    set plugin(all) [list]
+    set plugin(allPacks) [list]
+    set plugin(allInternalPacks) [list]
+    set plugin(allExternalPacks) [list]
+    set plugin(allApps) [list]
     
     foreach packAndPlat [array names plugin "*,platform"] {
 	
@@ -384,7 +442,7 @@ proc ::Plugins::CompileAndLoadPackages { } {
 	    
 		# Search for it! Be silent.
 		if {[string equal $plugin($name,type) "internal"]} {
-		    ::SplashScreen::SetMsg "[mc splashlook] $name..."
+		    ::Splash::SetMsg [mc "Looking for %s" $name]...
 		    if {![catch {
 			eval {package require} $plugin($name,pack)
 		    } msg]} {
@@ -426,7 +484,7 @@ proc ::Plugins::CompileAndLoadPackages { } {
 #       Systematically make the 'supSuff', 'supMacTypes', 
 #       'supportedMimeTypes', 'mimeType2Packages'.
 
-proc ::Plugins::PostProcessInfo { } {
+proc ::Plugins::PostProcessInfo {} {
     variable plugin
     variable supportedMimeTypes
     variable supSuff
@@ -438,7 +496,8 @@ proc ::Plugins::PostProcessInfo { } {
     # We add the tk library to the other ones.
     foreach name [concat tk $plugin(all)] {
 	if {$plugin($name,loaded)}  {
-	    
+	    set supSuff($name) [list]
+
 	    # Loop over all file MIME types supported by this specific package.
 	    foreach mimeType $plugin($name,mimes) {
 		
@@ -468,7 +527,9 @@ proc ::Plugins::PostProcessInfo { } {
 		    }
 		}
 	    }
-	    eval lappend supSuff(all) $supSuff($name)
+	    if {[llength $supSuff($name)]} {
+		eval lappend supSuff(all) $supSuff($name)
+	    }
 	    eval lappend supportedMimeTypes(all) $plugin($name,mimes)
 	}
     }
@@ -509,9 +570,6 @@ proc ::Plugins::PostProcessInfo { } {
 	set mimeTypeDoWhat($mime) $prefMimeType2Package($mime)
     }
     set prefMimeType2Package(image/gif) tk
-
-    # By default, no importing takes place, thus {}. WRONG!!!
-    #set prefMimeType2Package(text/plain) {}
 }
 
 # Plugins::GetAllPackages --
@@ -532,7 +590,7 @@ proc ::Plugins::GetAllPackages {{which all}} {
 	    return $plugin(allExternalPacks)
 	}
 	platform {
-	    set packList {}
+	    set packList [list]
 	    foreach name $plugin(all) {
 		if {$plugin($name,ishost)} {
 		    lappend packList $name
@@ -541,7 +599,7 @@ proc ::Plugins::GetAllPackages {{which all}} {
 	    return $packList	    
 	}
 	loaded {
-	    set packList {}
+	    set packList [list]
 	    foreach name $plugin(all) {
 		if {$plugin($name,loaded)} {
 		    lappend packList $name
@@ -557,7 +615,7 @@ proc ::Plugins::GetAllPackages {{which all}} {
 #       Create the 'typelist' option for the Open Image/Movie dialog and 
 #       standard text files.
 
-proc ::Plugins::MakeTypeListDialogOption { } {
+proc ::Plugins::MakeTypeListDialogOption {} {
     global this
     variable supSuff
     variable supMacTypes
@@ -571,20 +629,11 @@ proc ::Plugins::MakeTypeListDialogOption { } {
 	application {}
     }
     
-    if {$this(platform) == "macintosh"}  {
-	
-	# On Mac either file extension or 'type' must match.
-	set typelist(text) [list  \
-	  [list Text $supSuff(text)]  \
-	  [list Text {} $supMacTypes(text)] ]
-    } else {
-	set typelist(text) [list  \
-	  [list Text $supSuff(text)]]
-    }
+    set typelist(text) [list [list Text $supSuff(text)]]
     
     switch -- $this(platform) {
 	
-	macintosh - macosx - windows - unix {    
+	macosx - windows - unix {    
 	    set typelist(image) [list   \
 	      [list Image $supSuff(image)]  \
 	      [list Image {} $supMacTypes(image)] ]
@@ -644,15 +693,15 @@ proc ::Plugins::MakeTypeListDialogOption { } {
     set typelist(all) [concat $typelist(text) $typelist(binary)]
 }
 
-proc ::Plugins::InitHook { } {
-    
-    ::Plugins::VerifyPackagesForMimeTypes
-    if {[::Plugins::HavePackage QuickTimeTcl]} {
-	::Plugins::QuickTimeTclInitHook
-    }
-}
+# proc ::Plugins::InitHook {} {
+#     
+#     VerifyPackagesForMimeTypes
+#     if {[HavePackage QuickTimeTcl]} {
+# 	QuickTimeTclInitHook
+#     }
+# }
 
-proc ::Plugins::QuickTimeTclInitHook { } {
+proc ::Plugins::QuickTimeTclInitHook {} {
     
     ::WB::RegisterHandler QUICKTIME ::Import::QuickTimeHandler    
 }
@@ -671,7 +720,7 @@ proc ::Plugins::QuickTimeTclInitHook { } {
 # Results:
 #       updates the 'mimeTypeDoWhat' and 'prefMimeType2Package' arrays.
 
-proc ::Plugins::VerifyPackagesForMimeTypes { } {
+proc ::Plugins::VerifyPackagesForMimeTypes {} {
     global prefs
     variable plugin
     variable prefMimeType2Package
@@ -738,7 +787,7 @@ proc ::Plugins::GetPreferredPackageForMime {mime} {
     if {[info exists prefMimeType2Package($mime)]} {
 	return $prefMimeType2Package($mime)
     } else {
-	return ""
+	return
     }
 }
 
@@ -754,11 +803,11 @@ proc ::Plugins::GetPackageListForMime {mime} {
     if {[info exists mimeType2Packages($mime)]} {
 	return $mimeType2Packages($mime)
     } else {
-	return ""
+	return
     }
 }
 
-proc ::Plugins::GetPreferredPackageArr { } {
+proc ::Plugins::GetPreferredPackageArr {} {
     variable prefMimeType2Package
 
     return [array get prefMimeType2Package]
@@ -778,7 +827,7 @@ proc ::Plugins::GetDoWhatForMime {mime} {
     if {[info exists mimeTypeDoWhat($mime)]} {
 	return $mimeTypeDoWhat($mime)
     } else {
-	return ""
+	return
     }
 }
 
@@ -849,7 +898,7 @@ proc ::Plugins::SetDoWhatForMime {mime action} {
     set mimeTypeDoWhat($mime) $action
 }
 
-proc ::Plugins::GetDoWhatForMimeArr { } {
+proc ::Plugins::GetDoWhatForMimeArr {} {
     variable mimeTypeDoWhat
 
     return [array get mimeTypeDoWhat]
@@ -895,7 +944,7 @@ proc ::Plugins::GetType {name} {
     if {[info exists plugin($name,type)]} {
 	return $plugin($name,type)
     } else {
-	return ""
+	return
     }
 }
 
@@ -905,7 +954,7 @@ proc ::Plugins::GetTypeDesc {name} {
     if {[info exists plugin($name,type)]} {
 	return [::Plugins::GetDescForPlugType $plugin($name,type)]
     } else {
-	return ""
+	return
     }
 }
 
@@ -917,7 +966,7 @@ proc ::Plugins::GetSuffixes {key} {
     if {[info exists supSuff($key)]} {
 	return $supSuff($key)
     } else {
-	return ""
+	return
     }
 }
 
@@ -927,7 +976,7 @@ proc ::Plugins::GetDescForPlugin {name} {
     if {[info exists plugin($name,desc)]} {
 	return $plugin($name,desc)
     } else {
-	return ""
+	return
     }
 }
 
@@ -937,7 +986,7 @@ proc ::Plugins::GetDescForPlugType {plugtype} {
     if {[info exists plugType2DescArr($plugtype)]} {
 	return $plugType2DescArr($plugtype)
     } else {
-	return ""
+	return
     }
 }
 
@@ -1006,7 +1055,7 @@ proc ::Plugins::GetVersionForPackage {name} {
     if {[info exists plugin($name,ver)]} {
 	return $plugin($name,ver)
     } else {
-	return ""
+	return
     }
 }
 
@@ -1016,7 +1065,7 @@ proc ::Plugins::GetIconForPackage {doWhat size} {
     if {[info exists plugin($doWhat,icon,$size)]} {
 	return $plugin($doWhat,icon,$size)
     } else {
-	return ""
+	return
     }
 }
 
@@ -1084,12 +1133,12 @@ proc ::Plugins::Register {name defList canvasBindList} {
     
     ::Debug 2 "::Plugins::Register name=$name"
     
-    set defListDefaults {\
-      type          external          \
-      desc          ""                \
-      platform      ""                \
-      importProc    ""                \
-      mimes         ""                \
+    set defListDefaults {
+      type          external
+      desc          ""
+      platform      ""
+      importProc    ""
+      mimes         ""
     }    
     
     # Set default values that may be overwritten.
@@ -1154,7 +1203,7 @@ proc ::Plugins::RegisterCanvasClassBinds {name bindList} {
 proc ::Plugins::DeregisterCanvasClassBinds {{name {}}} {
     variable canvasClassBinds
 
-    if {$name == ""} {
+    if {$name eq ""} {
 	array unset canvasClassBinds
     } else {
 	array unset canvasClassBinds "${name},*"
@@ -1179,7 +1228,7 @@ proc ::Plugins::RegisterCanvasInstBinds {w name bindList} {
 proc ::Plugins::DeregisterCanvasInstBinds {w {name {}}} {
     variable canvasInstBinds
 
-    if {$name == ""} {
+    if {$name eq ""} {
 	array unset canvasInstBinds "${w},*"
     } else {
 	array unset canvasInstBinds "${w},${name},*"
@@ -1196,14 +1245,14 @@ proc ::Plugins::SetCanvasBinds {wcan oldTool newTool} {
     variable canvasClassBinds
     variable canvasInstBinds
     
-    ::Debug 3 "::Plugins::SetCanvasBinds oldTool=$oldTool, newTool=$newTool"
+    ::Debug 4 "::Plugins::SetCanvasBinds oldTool=$oldTool, newTool=$newTool"
 
     # Canvas class bindings.
     foreach key [array names canvasClassBinds *,name] {
 	set name $canvasClassBinds($key)
     
 	# Remove any previous binds.
-	if {($oldTool != "") && [info exists canvasClassBinds($name,$oldTool)]} {
+	if {($oldTool ne "") && [info exists canvasClassBinds($name,$oldTool)]} {
 	    foreach binds $canvasClassBinds($name,$oldTool) {
 		foreach {bindDef cmd} $binds {
 		    regsub -all {\\|&} $bindDef {\\\0} bindDef
@@ -1214,7 +1263,7 @@ proc ::Plugins::SetCanvasBinds {wcan oldTool newTool} {
 	}
 	
 	# Add registered binds.
-	set bindList {}
+	set bindList [list]
 	if {[info exists canvasClassBinds($name,$newTool)]} {
 	    set bindList [concat $bindList $canvasClassBinds($name,$newTool)]
 	}
@@ -1237,7 +1286,7 @@ proc ::Plugins::SetCanvasBinds {wcan oldTool newTool} {
 	set name $canvasInstBinds($key)
     
 	# Remove any previous binds.
-	if {($oldTool != "") && [info exists canvasInstBinds($wcan,$name,$oldTool)]} {
+	if {($oldTool ne "") && [info exists canvasInstBinds($wcan,$name,$oldTool)]} {
 	    foreach binds $canvasInstBinds($wcan,$name,$oldTool) {
 		foreach {bindDef cmd} $binds {
 		    regsub -all {\\|&} $bindDef {\\\0} bindDef
@@ -1248,7 +1297,7 @@ proc ::Plugins::SetCanvasBinds {wcan oldTool newTool} {
 	}
 	
 	# Add registered binds.
-	set bindList {}
+	set bindList [list]
 	if {[info exists canvasInstBinds($wcan,$name,$newTool)]} {
 	    set bindList [concat $bindList  \
 	      $canvasInstBinds($wcan,$name,$newTool)]
@@ -1269,30 +1318,15 @@ proc ::Plugins::SetCanvasBinds {wcan oldTool newTool} {
 
 # Preference pages -------------------------------------------------------------
 
-proc ::Plugins::InitPrefsHook { } {
-    global  prefs
-    
-    # Plugin ban list. Do not load these packages.
-    set prefs(pluginBanList) {}
-    ::Debug 2 "::Plugins::InitPrefsHook"
-    
-    ::PreferencesUtils::Add [list  \
-      [list prefs(pluginBanList)   prefs_pluginBanList   $prefs(pluginBanList)]]
-    
-    # Load all plugins available.
-    ::Plugins::SetBanList $prefs(pluginBanList)
-    ::Plugins::Init
-}
-
 proc ::Plugins::BuildPrefsHook {wtree nbframe} {
     
-    if {![$wtree isitem Whiteboard]} {
-	$wtree newitem {Whiteboard} -text [mc Whiteboard]
+    if {![::Preferences::HaveTableItem Whiteboard]} {
+	::Preferences::NewTableItem {Whiteboard} [mc "Whiteboard"]
     }
-    $wtree newitem {Whiteboard Plugins2} -text [mc Plugins]
+    ::Preferences::NewTableItem {Whiteboard Plugins2} [mc "Plugins"]
 
     set wpage [$nbframe page Plugins2]
-    ::Plugins::BuildPrefsPage $wpage
+    BuildPrefsPage $wpage
 }
 
 proc ::Plugins::BuildPrefsPage {page} {
@@ -1301,31 +1335,46 @@ proc ::Plugins::BuildPrefsPage {page} {
     variable prefplugins
     variable tmpPrefPlugins
 
-    # Conference (groupchat) stuff.
-    set labfr $page.fr
-    labelframe $labfr -text [mc {Plugin Control}]
-    pack $labfr -side top -anchor w -padx 8 -pady 4
-    set pbl [frame $labfr.frin]
-    pack $pbl -padx 10 -pady 6 -side left
+    set wc $page.c
+    ttk::frame $wc -padding [option get . notebookPageSmallPadding {}]
+    pack $wc -side top -anchor [option get . dialogAnchor {}]
+
+    set pbl $wc.fr
+    ttk::frame $pbl
+    pack  $pbl  -side top -anchor w
     
-    label ${pbl}.lhead -wraplength 300 -anchor w -justify left \
-      -text [mc prefplugctrl]
-    pack ${pbl}.lhead -padx 0 -pady 2 -side top -anchor w
+    set str [mc "Select the plugins you want to be loaded."]
+    append str " " [mc "Requires a restart of %s" $prefs(appName)].
+    ttk::label $pbl.lhead -wraplength 300 -justify left \
+      -text $str -padding {0 0 0 4}
+    pack $pbl.lhead -side top -anchor w
         
-    set pfr [frame ${pbl}.frpl]
+    set pfr $pbl.p
+    ttk::frame $pfr
     pack $pfr -side top -anchor w
+    
     set i 0
-    foreach plug [::Plugins::GetAllPackages platform] {
-	set icon [::Plugins::GetIconForPackage $plug 12]
-	if {$icon != ""} {
-	    label ${pfr}.i${i} -image $icon
-	    grid ${pfr}.i${i} -row $i -column 0 -sticky w
-	}
-	set tmpPrefPlugins($plug) [::Plugins::IsLoaded $plug]
+    foreach plug [GetAllPackages platform] {
+	set tmpPrefPlugins($plug) [IsLoaded $plug]
 	set prefplugins($plug) $tmpPrefPlugins($plug)
-	checkbutton ${pfr}.c${i} -anchor w -text " $plug"  \
+
+	ttk::checkbutton $pfr.c$i -text $plug  \
 	  -variable [namespace current]::tmpPrefPlugins($plug)
-	grid ${pfr}.c${i} -row $i -column 1 -padx 2 -sticky ew
+	grid  $pfr.c$i  -sticky w  -padx 4
+	
+	set tooltip [dict create]
+	dict set tooltip snack        [mc "Support for mp3, wav, and a few other audio formats"]
+	dict set tooltip Img          [mc "Support for common image formats"]
+	dict set tooltip tkpng        [mc "Support for PNG images"]
+	dict set tooltip xanim        [mc "Support for several animation, video and audio formats"]
+	dict set tooltip QuickTimeTcl [mc "Support for several animation, image, video and audio formats"]
+	dict set tooltip TextImporter [mc "Import plain text documents"]
+	dict set tooltip HtmlImport   [mc "Import HTML pages"]
+	dict set tooltip ItclApplets  [mc "Import Itcl applets"]
+	dict set tooltip WinImport    [mc "Import documents on Windows"]
+	
+	::balloonhelp::balloonforwindow $pfr.c$i [dict get $tooltip $plug]
+	
 	incr i
     }
     foreach plug $prefs(pluginBanList) {
@@ -1334,13 +1383,13 @@ proc ::Plugins::BuildPrefsPage {page} {
     }
 }
 
-proc ::Plugins::SaveHook { } {
+proc ::Plugins::SaveHook {} {
     global prefs
     variable prefplugins
     variable tmpPrefPlugins
     
     # To be correct we should also have loaded the pack here. TODO.
-    set banList {}
+    set banList [list]
     foreach name [array names tmpPrefPlugins] {
 	if {$tmpPrefPlugins($name) == 0} {
 	    lappend banList $name
@@ -1352,7 +1401,7 @@ proc ::Plugins::SaveHook { } {
     set prefs(pluginBanList) [lsort -unique $banList]
 }
 
-proc ::Plugins::CancelHook { } {
+proc ::Plugins::CancelHook {} {
     variable prefplugins
     variable tmpPrefPlugins
     
@@ -1365,7 +1414,7 @@ proc ::Plugins::CancelHook { } {
     }    
 }
 
-proc ::Plugins::UserDefaultsHook { } {
+proc ::Plugins::UserDefaultsHook {} {
     variable prefplugins
     variable tmpPrefPlugins
     
@@ -1375,7 +1424,7 @@ proc ::Plugins::UserDefaultsHook { } {
     }    
 }
 
-proc ::Plugins::DestroyPrefsHook { } {
+proc ::Plugins::DestroyPrefsHook {} {
     variable prefplugins
     variable tmpPrefPlugins
     
